import { defineNuxtModule, createResolver, addComponent, addImports, addServerImports, addTemplate, useNitro } from '@nuxt/kit';

const name = "nuxt-shiki";
const version = "0.0.2";

const module = defineNuxtModule({
  meta: {
    name,
    version,
    configKey: "shiki"
  },
  defaults: {
    themes: [],
    langs: [],
    theme: "github-light",
    lang: "javascript"
  },
  setup(options, nuxt) {
    const resolver = createResolver(import.meta.url);
    addUnwasmSupport(nuxt);
    addComponent({
      filePath: resolver.resolve("./runtime/Shiki"),
      name: "Shiki"
    });
    addImports([
      {
        name: "loadShiki",
        from: resolver.resolve("./runtime/loadShiki")
      },
      {
        name: "useHighlighted",
        from: resolver.resolve("./runtime/useHighlighted")
      }
    ]);
    addServerImports([
      {
        name: "loadShiki",
        from: resolver.resolve("./runtime/loadShiki")
      }
    ]);
    const themes = Array.from(/* @__PURE__ */ new Set([options.theme, ...options.themes]));
    const langs = Array.from(/* @__PURE__ */ new Set([options.lang, ...options.langs]));
    const template = addTemplate({
      filename: "shiki-config.mjs",
      getContents: () => {
        return `
export async function loadShikiConfig() {
  return {
    defaults: {
      lang: "${options.lang}",
      theme: "${options.theme}",
    },
    themes: await Promise.all([
      ${themes.map((theme) => `import("shiki/themes/${theme}.mjs"),`).join("\n")}
    ]),
    langs: await Promise.all([
      ${langs.map((lang) => `import("shiki/langs/${lang}.mjs"),`).join("\n")}
    ]),
  };
}`;
      }
    });
    nuxt.options.nitro.virtual = nuxt.options.nitro.virtual || {};
    nuxt.options.nitro.virtual["shiki-config.mjs"] = template.getContents;
    if (!nuxt.options.dev) {
      nuxt.options.alias["shiki-config.mjs"] = "#build/shiki-config.mjs";
    }
  }
});
function addUnwasmSupport(nuxt) {
  nuxt.hook("ready", () => {
    const nitro = useNitro();
    const addWasmSupport = (_nitro) => {
      if (nitro.options.experimental?.wasm) {
        return;
      }
      _nitro.options.externals = _nitro.options.externals || {};
      _nitro.options.externals.inline = _nitro.options.externals.inline || [];
      _nitro.options.externals.inline.push((id) => id.endsWith(".wasm"));
      _nitro.hooks.hook("rollup:before", async (_, rollupConfig) => {
        const { rollup: unwasm } = await import('unwasm/plugin');
        rollupConfig.plugins = rollupConfig.plugins || [];
        rollupConfig.plugins.push(
          unwasm({
            ..._nitro.options.wasm
          })
        );
      });
    };
    addWasmSupport(nitro);
    nitro.hooks.hook("prerender:init", (prerenderer) => {
      addWasmSupport(prerenderer);
    });
  });
}

export { module as default };
