import type { HighlighterCore, HighlighterCoreOptions } from 'shiki/core';
type ShikiInstance = HighlighterCore & {
    $defaults: {
        theme: string;
        lang: string;
    };
    $config: HighlighterCoreOptions & {
        defaultTheme: string;
        defaultLang: string;
    };
};
declare global {
    var __nuxt_shiki__: ShikiInstance | Promise<ShikiInstance>;
}
/**
 * Lazy-load shiki instance.
 *
 * You can use this utility both in `server/` and vue app code.
 *
 * @example
 *
 * ```vue
<script setup>
const shiki = await loadShiki();
const html = shiki.codeToHtml('const hello = "shiki";', {
  ...$shiki.$defaults,
  lang: "javascript",
});
</script>
 * ```
 *
 * @example
 *
 * ```ts
// server/api/highlight.ts

export default defineEventHandler(async (event) => {
  const shiki = await loadShiki();
  return shiki.codeToHtml('const hello = "shiki"', { ...$shiki.$defaults });
});
 * ```
 */
export declare function loadShiki(): Promise<ShikiInstance>;
export {};
