import { ref, watchEffect, watch, isRef } from "vue";
import { loadShiki } from "./loadShiki.mjs";
export async function useHighlighted(code, options = {}) {
  const _code = isRef(code) ? code : ref(code);
  if (import.meta.server) {
    const shiki = await loadShiki();
    return ref(
      shiki.codeToHtml(_code.value, {
        ...shiki.$defaults,
        ...options
      })
    );
  }
  const highlighted = ref(options.highlighted || "");
  if (highlighted.value) {
    const unwatch = watch(_code, () => {
      unwatch();
      init();
    });
  } else {
    await init();
  }
  function init() {
    loadShiki().then((shiki) => {
      watchEffect(() => {
        highlighted.value = shiki.codeToHtml(_code.value, {
          ...shiki.$defaults,
          ...options
        });
      });
    });
  }
  return highlighted;
}
